Update v5.15 patches

Changes:
 - Revert Surface Aggregator hot-removal changes for Surface Book 3 as
   they have caused problems.
 - Rebase onto v5.15.5

Links:
 - kernel: 91cb554518
This commit is contained in:
Maximilian Luz 2021-11-29 11:58:12 +01:00
parent e81b118066
commit af73a111f6
No known key found for this signature in database
GPG key ID: 70EC0937F6C26F02
13 changed files with 189 additions and 638 deletions

View file

@ -1,4 +1,4 @@
From d842cdee383af6ed4bf26c061795f45f7ae8bc3d Mon Sep 17 00:00:00 2001
From aa5c6b07b36d96ff8a44d3fd31e3c270a1d424db Mon Sep 17 00:00:00 2001
From: Tsuchiya Yuto <kitakar@gmail.com>
Date: Sun, 18 Oct 2020 16:42:44 +0900
Subject: [PATCH] (surface3-oemb) add DMI matches for Surface 3 with broken DMI
@ -97,5 +97,5 @@ index 227424236fd5..1013a57be89a 100644
};
--
2.34.0
2.34.1

View file

@ -1,4 +1,4 @@
From 70099cdad05c8b78fba51a914874e70424ef7270 Mon Sep 17 00:00:00 2001
From 2a61d386b2e292a6d87170f7575231726295bac7 Mon Sep 17 00:00:00 2001
From: Tsuchiya Yuto <kitakar@gmail.com>
Date: Tue, 29 Sep 2020 17:32:22 +0900
Subject: [PATCH] mwifiex: pcie: add reset_wsid quirk for Surface 3
@ -181,9 +181,9 @@ index 8ec4176d698f..25370c5a4f59 100644
int mwifiex_pcie_reset_d3cold_quirk(struct pci_dev *pdev);
+int mwifiex_pcie_reset_wsid_quirk(struct pci_dev *pdev);
--
2.34.0
2.34.1
From f56fad8c5bcbef38d21bc29c6a0ae6db6b3511e1 Mon Sep 17 00:00:00 2001
From 44a8339560cc10c6708920f91298db1fe117877d Mon Sep 17 00:00:00 2001
From: Tsuchiya Yuto <kitakar@gmail.com>
Date: Wed, 30 Sep 2020 18:08:24 +0900
Subject: [PATCH] mwifiex: pcie: (OEMB) add quirk for Surface 3 with broken DMI
@ -243,9 +243,9 @@ index 563dd0d5ac79..32e2f000e57b 100644
};
--
2.34.0
2.34.1
From 4f463933ef0addec9fa5eab8916b2df5c4c78f8a Mon Sep 17 00:00:00 2001
From 2c7ff89670b65a2cb343cf30761ccd67b00daf68 Mon Sep 17 00:00:00 2001
From: Tsuchiya Yuto <kitakar@gmail.com>
Date: Sun, 4 Oct 2020 00:11:49 +0900
Subject: [PATCH] mwifiex: pcie: disable bridge_d3 for Surface gen4+
@ -398,9 +398,9 @@ index 25370c5a4f59..a1de111ad1db 100644
void mwifiex_initialize_quirks(struct pcie_service_card *card);
int mwifiex_pcie_reset_d3cold_quirk(struct pci_dev *pdev);
--
2.34.0
2.34.1
From 7de13212b8480f35c63f4b49e9f9cc6ee610f192 Mon Sep 17 00:00:00 2001
From ed94f990020938cf063e9e184b6981961c315c10 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Tue, 3 Nov 2020 13:28:04 +0100
Subject: [PATCH] mwifiex: Add quirk resetting the PCI bridge on MS Surface
@ -565,9 +565,9 @@ index a1de111ad1db..0e429779bb04 100644
void mwifiex_initialize_quirks(struct pcie_service_card *card);
int mwifiex_pcie_reset_d3cold_quirk(struct pci_dev *pdev);
--
2.34.0
2.34.1
From 0992af2af4793f4cfd8b2eb2c09d953d65681f6c Mon Sep 17 00:00:00 2001
From 986ce2e5b06ae7acf47530b0a5862386e7602154 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Thu, 25 Mar 2021 11:33:02 +0100
Subject: [PATCH] Bluetooth: btusb: Lower passive lescan interval on Marvell
@ -603,7 +603,7 @@ Patchset: mwifiex
1 file changed, 15 insertions(+)
diff --git a/drivers/bluetooth/btusb.c b/drivers/bluetooth/btusb.c
index 60d2fce59a71..48b4b02d93af 100644
index 79d0db542da3..ec96f3e7ad33 100644
--- a/drivers/bluetooth/btusb.c
+++ b/drivers/bluetooth/btusb.c
@@ -60,6 +60,7 @@ static struct usb_driver btusb_driver;
@ -622,7 +622,7 @@ index 60d2fce59a71..48b4b02d93af 100644
/* Intel Bluetooth devices */
{ USB_DEVICE(0x8087, 0x0025), .driver_info = BTUSB_INTEL_COMBINED },
@@ -3813,6 +3815,19 @@ static int btusb_probe(struct usb_interface *intf,
@@ -3817,6 +3819,19 @@ static int btusb_probe(struct usb_interface *intf,
if (id->driver_info & BTUSB_MARVELL)
hdev->set_bdaddr = btusb_set_bdaddr_marvell;
@ -643,9 +643,9 @@ index 60d2fce59a71..48b4b02d93af 100644
(id->driver_info & BTUSB_MEDIATEK)) {
hdev->setup = btusb_mtk_setup;
--
2.34.0
2.34.1
From 40b534763632bb82399a47424b906340d7561670 Mon Sep 17 00:00:00 2001
From ad921e4a01fb6650843d9e8aeaa0c47560265553 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Wed, 11 Nov 2020 12:31:26 +0100
Subject: [PATCH] mwifiex: Small cleanup for handling virtual interface type
@ -744,9 +744,9 @@ index 97f0f39364d6..dd30d21edc01 100644
mwifiex_dbg(priv->adapter, ERROR,
"%s: changing to %d not supported\n",
--
2.34.0
2.34.1
From 06c60dfe5d373ab8616458d508ab96c8994cafa4 Mon Sep 17 00:00:00 2001
From ae35ad52495643b7805eb78bcec62d0ba33c9f2a Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Tue, 10 Nov 2020 12:49:56 +0100
Subject: [PATCH] mwifiex: Use non-posted PCI register writes
@ -801,9 +801,9 @@ index 586c79dc0a98..f87bc9bdfba7 100644
}
--
2.34.0
2.34.1
From 7d0809a4c92840c16eada1eb93e01c750c4e8fb5 Mon Sep 17 00:00:00 2001
From 21bea4b8c6e038e66613e319de1706f99b66bebc Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Wed, 11 Nov 2020 12:44:39 +0100
Subject: [PATCH] mwifiex: Use function to check whether interface type change
@ -1034,9 +1034,9 @@ index dd30d21edc01..e4d44705c827 100644
static void
--
2.34.0
2.34.1
From 792e946addb9f9b268ed0691f6d588d1e27eb5b6 Mon Sep 17 00:00:00 2001
From 079426b90b0a845a7b2e5c5f71393c7f9ade0e47 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Wed, 11 Nov 2020 14:42:54 +0100
Subject: [PATCH] mwifiex: Use helper function for counting interface types
@ -1210,9 +1210,9 @@ index e4d44705c827..a688fd898564 100644
priv->bss_mode = NL80211_IFTYPE_UNSPECIFIED;
--
2.34.0
2.34.1
From ed93663cd2a45a085b8a16e0c1dd3d47d5043ab4 Mon Sep 17 00:00:00 2001
From fa1fe1c9e8c473983492c1d9645892b0048e8190 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Fri, 26 Mar 2021 15:56:58 +0100
Subject: [PATCH] mwifiex: Update virtual interface counters right after
@ -1313,9 +1313,9 @@ index a688fd898564..2a938e8e0bb1 100644
}
/*
--
2.34.0
2.34.1
From 48bf48c76bd3fd072c2897f9cfd6d0f210cff8ea Mon Sep 17 00:00:00 2001
From 72307e76555170190a8344c6872e02634deceeee Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Wed, 11 Nov 2020 13:42:40 +0100
Subject: [PATCH] mwifiex: Allow switching interface type from P2P_CLIENT to
@ -1402,9 +1402,9 @@ index 2a938e8e0bb1..2a3f9ebb3182 100644
return mwifiex_change_vif_to_ap(dev, curr_iftype, type,
params);
--
2.34.0
2.34.1
From 7f417221b0c2f738eb9b763d7b230b3e29ff3110 Mon Sep 17 00:00:00 2001
From 86253b78e05e9b20604680606f7cf002cd62c978 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Fri, 26 Mar 2021 15:31:08 +0100
Subject: [PATCH] mwifiex: Handle interface type changes from AP to STATION
@ -1429,9 +1429,9 @@ index 2a3f9ebb3182..0eb31201a82b 100644
type, params);
break;
--
2.34.0
2.34.1
From 07d9812b1284179a7d7c6aedb1d03f472ea301e4 Mon Sep 17 00:00:00 2001
From 106d74d8e3d274559655831609c46329a05f075d Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Sat, 27 Mar 2021 12:19:14 +0100
Subject: [PATCH] mwifiex: Fix copy-paste mistake when creating virtual
@ -1461,9 +1461,9 @@ index 0eb31201a82b..d62a20de3ada 100644
priv->bss_started = 0;
--
2.34.0
2.34.1
From f5216fd483ed9b5c4a5d4cc87d891aac83f5f6b6 Mon Sep 17 00:00:00 2001
From 82dc821d865325684647b722ffad680d6a4d6262 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Tue, 13 Apr 2021 14:30:28 +0200
Subject: [PATCH] mwifiex: Deactive host sleep using HSCFG after it was
@ -1617,9 +1617,9 @@ index 48ea00da1fc9..1e2798dce18f 100644
hs_cfg->action = cpu_to_le16(HS_CONFIGURE);
hs_cfg->params.hs_config.conditions = hscfg_param->conditions;
--
2.34.0
2.34.1
From bbdd04b2f9a7f870c18bf075e4695a034d16ba9a Mon Sep 17 00:00:00 2001
From db0e65ebb5aef450eeb7bc0795c0c0c92610acae Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Tue, 13 Apr 2021 14:23:05 +0200
Subject: [PATCH] mwifiex: Add quirk to disable deep sleep with certain
@ -1720,9 +1720,9 @@ index 6b5d35d9e69f..8e49ebca1847 100644
version_ext->version_str_sel = ver_ext->version_str_sel;
memcpy(version_ext->version_str, ver_ext->version_str,
--
2.34.0
2.34.1
From 5c123be8003a8c0c8546177232e79b5f594ac548 Mon Sep 17 00:00:00 2001
From 75b3d30861f76b7a12700aa08d8c24cb9193b00a Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Wed, 11 Nov 2020 15:17:07 +0100
Subject: [PATCH] mwifiex: Don't log error on suspend if wake-on-wlan is
@ -1752,9 +1752,9 @@ index d62a20de3ada..18b1a6d54bc8 100644
ret = 0;
goto done;
--
2.34.0
2.34.1
From 7cdd3b18f7d8d65368f1886e47542ad72719c328 Mon Sep 17 00:00:00 2001
From f6131d38ce61539b420368d8c49d8d6ef5abeff8 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Sun, 28 Mar 2021 21:42:54 +0200
Subject: [PATCH] mwifiex: Log an error on command failure during key-material
@ -1792,9 +1792,9 @@ index 18b1a6d54bc8..c00791701d78 100644
/*
--
2.34.0
2.34.1
From 9e235520bd33fff9ee22fcf7a08c58c336c7906f Mon Sep 17 00:00:00 2001
From bc5424a6fe1b25a6f2cf8152833a82ef495b5739 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Tue, 13 Apr 2021 12:44:03 +0200
Subject: [PATCH] mwifiex: Fix an incorrect comment
@ -1820,9 +1820,9 @@ index cf08a4af84d6..9ff2058bcd7e 100644
if (!INITIATOR_BIT(del_ba_param_set))
return 0;
--
2.34.0
2.34.1
From 59d70eff6bf0bd37a8bf0276829ff5725d3e7bb7 Mon Sep 17 00:00:00 2001
From 239555ad4c9d63918d42faca195859f5bc6ec54e Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Tue, 13 Apr 2021 12:57:41 +0200
Subject: [PATCH] mwifiex: Ignore BTCOEX events from the firmware
@ -1858,5 +1858,5 @@ index 68c63268e2e6..933111a3511c 100644
case EVENT_RXBA_SYNC:
dev_dbg(adapter->dev, "EVENT: RXBA_SYNC\n");
--
2.34.0
2.34.1

View file

@ -1,4 +1,4 @@
From c53af7a0dc326f2106b010d1cc8cc68234ddd1c7 Mon Sep 17 00:00:00 2001
From a9bba505cfca0dace42755b3bcebe764eda71d98 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Sat, 27 Feb 2021 00:45:52 +0100
Subject: [PATCH] ath10k: Add module parameters to override board files
@ -117,5 +117,5 @@ index 64c7145b51a2..1e71a60cfb11 100644
ret = firmware_request_nowarn(&fw, filename, ar->dev);
ath10k_dbg(ar, ATH10K_DBG_BOOT, "boot fw request '%s': %d\n",
--
2.34.0
2.34.1

View file

@ -1,4 +1,4 @@
From b7225aa16a7d1870585fe459d5c96662cf7841d0 Mon Sep 17 00:00:00 2001
From e8e1223a32633529bbe63e58a44d665c2e4cf081 Mon Sep 17 00:00:00 2001
From: Dorian Stoll <dorian.stoll@tmsp.io>
Date: Thu, 30 Jul 2020 13:21:53 +0200
Subject: [PATCH] misc: mei: Add missing IPTS device IDs
@ -34,9 +34,9 @@ index 3a45aaf002ac..55b8ee30a03c 100644
{MEI_PCI_DEVICE(MEI_DEV_ID_TGP_LP, MEI_ME_PCH15_CFG)},
--
2.34.0
2.34.1
From 6bff305ba49497e93bf313553411f66963294f11 Mon Sep 17 00:00:00 2001
From ae492c77a063760972e48841ed540d170e7b76de Mon Sep 17 00:00:00 2001
From: Dorian Stoll <dorian.stoll@tmsp.io>
Date: Thu, 6 Aug 2020 11:20:41 +0200
Subject: [PATCH] misc: Add support for Intel Precise Touch & Stylus
@ -1499,5 +1499,5 @@ index 000000000000..53fb86a88f97
+
+#endif /* _IPTS_UAPI_H_ */
--
2.34.0
2.34.1

View file

@ -1,4 +1,4 @@
From 496d12ef24c37996450d8f9ea53b4a86440be323 Mon Sep 17 00:00:00 2001
From 7a062af254fb0bfca0fb35f93fcaa0126692dd7e Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Thu, 28 Oct 2021 03:28:45 +0200
Subject: [PATCH] platform/surface: aggregator_registry: Add initial support
@ -56,9 +56,9 @@ index 1679811eff50..e70f4c63554e 100644
{ "MSHW0107", (unsigned long)ssam_node_group_gen5 },
--
2.34.0
2.34.1
From 510309d4e8736c0c89929f433fe3af06880b9d8a Mon Sep 17 00:00:00 2001
From 01b41cf45677d2d2bd0279de09b9cd63212e0046 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Wed, 2 Jun 2021 03:34:06 +0200
Subject: [PATCH] platform/surface: aggregator: Make client device removal more
@ -181,9 +181,9 @@ index f636c5310321..cc257097eb05 100644
/**
--
2.34.0
2.34.1
From d59bcb9435c687d11ff535bad01244c3d6bf77e8 Mon Sep 17 00:00:00 2001
From ceca307e9cba98e45560c70f6aacfc03330f5840 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Wed, 27 Oct 2021 02:06:38 +0200
Subject: [PATCH] platform/surface: aggregator_registry: Use generic client
@ -269,9 +269,9 @@ index e70f4c63554e..f6c639342b9d 100644
software_node_unregister_node_group(nodes);
return 0;
--
2.34.0
2.34.1
From 0e08c63523a2b62206efd172eb25022829cc4bce Mon Sep 17 00:00:00 2001
From 976a6345f68996abd0a4fbdce40f635c19a6a854 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Wed, 27 Oct 2021 02:07:33 +0200
Subject: [PATCH] platform/surface: aggregator_registry: Rename device
@ -320,9 +320,9 @@ index f6c639342b9d..ce2bd88feeaa 100644
set_secondary_fwnode(&pdev->dev, NULL);
software_node_unregister_node_group(nodes);
--
2.34.0
2.34.1
From 886b35d68277037c6ba36024bdb56d3a0b3a9582 Mon Sep 17 00:00:00 2001
From 55b54fe60ce380e6ae486277b3d73cf9d972cbc7 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Tue, 8 Jun 2021 00:24:47 +0200
Subject: [PATCH] platform/surface: aggregator: Allow devices to be marked as
@ -441,9 +441,9 @@ index cc257097eb05..491aa7e9f4bc 100644
* ssam_device_get() - Increment reference count of SSAM client device.
* @sdev: The device to increment the reference count of.
--
2.34.0
2.34.1
From c7bd6479e8b468ade6e0c15d5adabb3c1d8cb3f9 Mon Sep 17 00:00:00 2001
From 92146078e5542d87b15669361a14110c4b6b1739 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Tue, 8 Jun 2021 00:48:22 +0200
Subject: [PATCH] platform/surface: aggregator: Allow notifiers to avoid
@ -728,9 +728,9 @@ index 491aa7e9f4bc..16816c34da3e 100644
+
#endif /* _LINUX_SURFACE_AGGREGATOR_DEVICE_H */
--
2.34.0
2.34.1
From faf10ea439805d6624240df0e8d20c3b7de2fb0b Mon Sep 17 00:00:00 2001
From 35d2b15b2bfdadc844678ea2596cc613c7568562 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Tue, 8 Jun 2021 01:20:49 +0200
Subject: [PATCH] platform/surface: aggregator_registry: Use client device
@ -777,9 +777,9 @@ index ce2bd88feeaa..9f630e890ff7 100644
ssam_remove_clients(&sdev->dev);
}
--
2.34.0
2.34.1
From ed9f7aa089ba6c8d6804ca9848ea2a36e3ebfd05 Mon Sep 17 00:00:00 2001
From e30843b08ba4ef74dcb2306db77124d781ead920 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Thu, 28 Oct 2021 03:37:06 +0200
Subject: [PATCH] power/supply: surface_charger: Use client device wrappers for
@ -817,9 +817,9 @@ index a060c36c7766..59182d55742d 100644
static const struct spwr_psy_properties spwr_psy_props_adp1 = {
--
2.34.0
2.34.1
From da9cc91d8244343358c7da76f22067b7ce130b20 Mon Sep 17 00:00:00 2001
From a1c90203399ea0f2ea8846a631bf218cd58af128 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Thu, 28 Oct 2021 03:38:09 +0200
Subject: [PATCH] power/supply: surface_battery: Use client device wrappers for
@ -857,9 +857,9 @@ index 5ec2e6bb2465..540707882bb0 100644
}
--
2.34.0
2.34.1
From 096356dbf0b8fa07ae9fa04c0548a568db114bb1 Mon Sep 17 00:00:00 2001
From f1ca8e0f72d5513a8ba5c12538cfbbfebc730837 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Tue, 8 Jun 2021 01:33:02 +0200
Subject: [PATCH] HID: surface-hid: Add support for hot-removal
@ -968,9 +968,9 @@ index 5571e74abe91..d2e695e942b6 100644
return shid->ops.output_report(shid, reportnum, buf, len);
--
2.34.0
2.34.1
From bc7cfd188a34429c599f32a77d2dceeae0f8674d Mon Sep 17 00:00:00 2001
From e6d33d4464f41358ef24c3cdb23a8c289fcc1858 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Sun, 31 Oct 2021 12:34:08 +0100
Subject: [PATCH] platform/surface: aggregator: Add comment for KIP subsystem
@ -1006,9 +1006,9 @@ index c3de43edcffa..d1efac85caf1 100644
SSAM_SSH_TC_BLD = 0x10,
SSAM_SSH_TC_BAS = 0x11, /* Detachment system (Surface Book 2/3). */
--
2.34.0
2.34.1
From 7ca9a066f94cd01d1c2b2498e0ebd6e283b9649d Mon Sep 17 00:00:00 2001
From 3bdd0aceeb1073fa84b80fb00aec5304ce294c70 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Sun, 10 Oct 2021 23:56:23 +0200
Subject: [PATCH] platform/surface: aggregator_registry: Add KIP device hub
@ -1320,9 +1320,9 @@ index 9f630e890ff7..4838ce6519a6 100644
platform_driver_unregister(&ssam_platform_hub_driver);
}
--
2.34.0
2.34.1
From 1598a4c2c6eb031c15ae2bb3df90d34edae51b89 Mon Sep 17 00:00:00 2001
From 2ec1190e86f426b2c8d98797ae2a448abcb8e2bb Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Wed, 27 Oct 2021 22:33:03 +0200
Subject: [PATCH] platform/surface: aggregator_registry: Add support for
@ -1418,9 +1418,9 @@ index 4838ce6519a6..c0e29c0514df 100644
};
--
2.34.0
2.34.1
From 1583027b968654e2cd12b6860423cb0fb75d5629 Mon Sep 17 00:00:00 2001
From 9b9b2b45bff1ff5bc1a64de0ee3a21074198aa3a Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Tue, 8 Jun 2021 03:19:20 +0200
Subject: [PATCH] platform/surface: Add KIP tablet-mode switch
@ -1762,9 +1762,9 @@ index 000000000000..458470067579
+MODULE_DESCRIPTION("Tablet mode switch driver for Surface devices using KIP subsystem");
+MODULE_LICENSE("GPL");
--
2.34.0
2.34.1
From 4109ded6a4d089e203e7b7c25984892f10e91f0a Mon Sep 17 00:00:00 2001
From 226ea66ac2a99ef2c7c17d3d2b9e164d2d3efa00 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Wed, 27 Oct 2021 22:33:03 +0200
Subject: [PATCH] platform/surface: aggregator_registry: Add support for tablet
@ -1812,454 +1812,5 @@ index c0e29c0514df..eaf0054627a5 100644
};
--
2.34.0
From 4be5a5872682bd890911a48cee79f7f583ff4686 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Thu, 28 Oct 2021 03:40:22 +0200
Subject: [PATCH] power/supply: surface_battery: Add support for hot-removal
In cases of hot-removal, further communication with the device should be
avoided whenever possible, as it may fail and time out.
Signed-off-by: Maximilian Luz <luzmaximilian@gmail.com>
Patchset: surface-sam
---
drivers/power/supply/surface_battery.c | 6 ++++++
1 file changed, 6 insertions(+)
diff --git a/drivers/power/supply/surface_battery.c b/drivers/power/supply/surface_battery.c
index 540707882bb0..ebf1f96e9a89 100644
--- a/drivers/power/supply/surface_battery.c
+++ b/drivers/power/supply/surface_battery.c
@@ -156,6 +156,9 @@ static bool spwr_battery_present(struct spwr_battery_device *bat)
{
lockdep_assert_held(&bat->lock);
+ if (ssam_device_is_hot_removed(bat->sdev))
+ return false;
+
return le32_to_cpu(bat->sta) & SAM_BATTERY_STA_PRESENT;
}
@@ -245,6 +248,9 @@ static int spwr_battery_update_bix_unlocked(struct spwr_battery_device *bat)
lockdep_assert_held(&bat->lock);
+ if (ssam_device_is_hot_removed(bat->sdev))
+ return 0;
+
status = spwr_battery_load_sta(bat);
if (status)
return status;
--
2.34.0
From 4317a9568b04494977bf91edab24a0148aaa9329 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Sun, 31 Oct 2021 18:09:53 +0100
Subject: [PATCH] platform/surface: aggregator_registry: Remove base hub driver
The base hub was a virtual device hub for Surface System Aggregator
Module (SSAM) client devices contained in the detachable Surface Book 3
base. Remove it as it is no longer needed.
In the previous change, we have moved all devices from the base hub to
the KIP hub. That change has also removed the only base-hub-device that
ever existed, as it was essentially replaced by the KIP-hub-device and
thus was no longer needed. This means that there is no remaining
hub-device against which the base hub driver can load, i.e. it is now
essentially dead code. So remove the driver as well.
Signed-off-by: Maximilian Luz <luzmaximilian@gmail.com>
Patchset: surface-sam
---
.../surface/surface_aggregator_registry.c | 213 ------------------
1 file changed, 213 deletions(-)
diff --git a/drivers/platform/surface/surface_aggregator_registry.c b/drivers/platform/surface/surface_aggregator_registry.c
index d17f656b2dad..590473220e9d 100644
--- a/drivers/platform/surface/surface_aggregator_registry.c
+++ b/drivers/platform/surface/surface_aggregator_registry.c
@@ -325,212 +325,6 @@ static int ssam_hub_register_clients(struct device *parent, struct ssam_controll
}
-/* -- SSAM base-hub driver. ------------------------------------------------- */
-
-/*
- * Some devices (especially battery) may need a bit of time to be fully usable
- * after being (re-)connected. This delay has been determined via
- * experimentation.
- */
-#define SSAM_BASE_UPDATE_CONNECT_DELAY msecs_to_jiffies(2500)
-
-enum ssam_base_hub_state {
- SSAM_BASE_HUB_UNINITIALIZED,
- SSAM_BASE_HUB_CONNECTED,
- SSAM_BASE_HUB_DISCONNECTED,
-};
-
-struct ssam_base_hub {
- struct ssam_device *sdev;
-
- enum ssam_base_hub_state state;
- struct delayed_work update_work;
-
- struct ssam_event_notifier notif;
-};
-
-SSAM_DEFINE_SYNC_REQUEST_R(ssam_bas_query_opmode, u8, {
- .target_category = SSAM_SSH_TC_BAS,
- .target_id = 0x01,
- .command_id = 0x0d,
- .instance_id = 0x00,
-});
-
-#define SSAM_BAS_OPMODE_TABLET 0x00
-#define SSAM_EVENT_BAS_CID_CONNECTION 0x0c
-
-static int ssam_base_hub_query_state(struct ssam_base_hub *hub, enum ssam_base_hub_state *state)
-{
- u8 opmode;
- int status;
-
- status = ssam_retry(ssam_bas_query_opmode, hub->sdev->ctrl, &opmode);
- if (status < 0) {
- dev_err(&hub->sdev->dev, "failed to query base state: %d\n", status);
- return status;
- }
-
- if (opmode != SSAM_BAS_OPMODE_TABLET)
- *state = SSAM_BASE_HUB_CONNECTED;
- else
- *state = SSAM_BASE_HUB_DISCONNECTED;
-
- return 0;
-}
-
-static ssize_t ssam_base_hub_state_show(struct device *dev, struct device_attribute *attr,
- char *buf)
-{
- struct ssam_base_hub *hub = dev_get_drvdata(dev);
- bool connected = hub->state == SSAM_BASE_HUB_CONNECTED;
-
- return sysfs_emit(buf, "%d\n", connected);
-}
-
-static struct device_attribute ssam_base_hub_attr_state =
- __ATTR(state, 0444, ssam_base_hub_state_show, NULL);
-
-static struct attribute *ssam_base_hub_attrs[] = {
- &ssam_base_hub_attr_state.attr,
- NULL,
-};
-
-static const struct attribute_group ssam_base_hub_group = {
- .attrs = ssam_base_hub_attrs,
-};
-
-static void ssam_base_hub_update_workfn(struct work_struct *work)
-{
- struct ssam_base_hub *hub = container_of(work, struct ssam_base_hub, update_work.work);
- struct fwnode_handle *node = dev_fwnode(&hub->sdev->dev);
- enum ssam_base_hub_state state;
- int status = 0;
-
- status = ssam_base_hub_query_state(hub, &state);
- if (status)
- return;
-
- if (hub->state == state)
- return;
- hub->state = state;
-
- if (hub->state == SSAM_BASE_HUB_CONNECTED)
- status = ssam_hub_register_clients(&hub->sdev->dev, hub->sdev->ctrl, node);
- else
- ssam_remove_clients(&hub->sdev->dev);
-
- if (status)
- dev_err(&hub->sdev->dev, "failed to update base-hub devices: %d\n", status);
-}
-
-static u32 ssam_base_hub_notif(struct ssam_event_notifier *nf, const struct ssam_event *event)
-{
- struct ssam_base_hub *hub = container_of(nf, struct ssam_base_hub, notif);
- unsigned long delay;
-
- if (event->command_id != SSAM_EVENT_BAS_CID_CONNECTION)
- return 0;
-
- if (event->length < 1) {
- dev_err(&hub->sdev->dev, "unexpected payload size: %u\n", event->length);
- return 0;
- }
-
- /*
- * Delay update when the base is being connected to give devices/EC
- * some time to set up.
- */
- delay = event->data[0] ? SSAM_BASE_UPDATE_CONNECT_DELAY : 0;
-
- schedule_delayed_work(&hub->update_work, delay);
-
- /*
- * Do not return SSAM_NOTIF_HANDLED: The event should be picked up and
- * consumed by the detachment system driver. We're just a (more or less)
- * silent observer.
- */
- return 0;
-}
-
-static int __maybe_unused ssam_base_hub_resume(struct device *dev)
-{
- struct ssam_base_hub *hub = dev_get_drvdata(dev);
-
- schedule_delayed_work(&hub->update_work, 0);
- return 0;
-}
-static SIMPLE_DEV_PM_OPS(ssam_base_hub_pm_ops, NULL, ssam_base_hub_resume);
-
-static int ssam_base_hub_probe(struct ssam_device *sdev)
-{
- struct ssam_base_hub *hub;
- int status;
-
- hub = devm_kzalloc(&sdev->dev, sizeof(*hub), GFP_KERNEL);
- if (!hub)
- return -ENOMEM;
-
- hub->sdev = sdev;
- hub->state = SSAM_BASE_HUB_UNINITIALIZED;
-
- hub->notif.base.priority = INT_MAX; /* This notifier should run first. */
- hub->notif.base.fn = ssam_base_hub_notif;
- hub->notif.event.reg = SSAM_EVENT_REGISTRY_SAM;
- hub->notif.event.id.target_category = SSAM_SSH_TC_BAS,
- hub->notif.event.id.instance = 0,
- hub->notif.event.mask = SSAM_EVENT_MASK_NONE;
- hub->notif.event.flags = SSAM_EVENT_SEQUENCED;
-
- INIT_DELAYED_WORK(&hub->update_work, ssam_base_hub_update_workfn);
-
- ssam_device_set_drvdata(sdev, hub);
-
- status = ssam_device_notifier_register(sdev, &hub->notif);
- if (status)
- return status;
-
- status = sysfs_create_group(&sdev->dev.kobj, &ssam_base_hub_group);
- if (status)
- goto err;
-
- schedule_delayed_work(&hub->update_work, 0);
- return 0;
-
-err:
- ssam_device_notifier_unregister(sdev, &hub->notif);
- cancel_delayed_work_sync(&hub->update_work);
- ssam_remove_clients(&sdev->dev);
- return status;
-}
-
-static void ssam_base_hub_remove(struct ssam_device *sdev)
-{
- struct ssam_base_hub *hub = ssam_device_get_drvdata(sdev);
-
- sysfs_remove_group(&sdev->dev.kobj, &ssam_base_hub_group);
-
- ssam_device_notifier_unregister(sdev, &hub->notif);
- cancel_delayed_work_sync(&hub->update_work);
- ssam_remove_clients(&sdev->dev);
-}
-
-static const struct ssam_device_id ssam_base_hub_match[] = {
- { SSAM_VDEV(HUB, 0x02, SSAM_ANY_IID, 0x00) },
- { },
-};
-
-static struct ssam_device_driver ssam_base_hub_driver = {
- .probe = ssam_base_hub_probe,
- .remove = ssam_base_hub_remove,
- .match_table = ssam_base_hub_match,
- .driver = {
- .name = "surface_aggregator_base_hub",
- .probe_type = PROBE_PREFER_ASYNCHRONOUS,
- .pm = &ssam_base_hub_pm_ops,
- },
-};
-
-
/* -- SSAM KIP-subsystem hub driver. ---------------------------------------- */
/*
@@ -886,10 +680,6 @@ static int __init ssam_device_hub_init(void)
if (status)
goto err_platform;
- status = ssam_device_driver_register(&ssam_base_hub_driver);
- if (status)
- goto err_base;
-
status = ssam_device_driver_register(&ssam_kip_hub_driver);
if (status)
goto err_kip;
@@ -897,8 +687,6 @@ static int __init ssam_device_hub_init(void)
return 0;
err_kip:
- ssam_device_driver_unregister(&ssam_base_hub_driver);
-err_base:
platform_driver_unregister(&ssam_platform_hub_driver);
err_platform:
return status;
@@ -908,7 +696,6 @@ module_init(ssam_device_hub_init);
static void __exit ssam_device_hub_exit(void)
{
ssam_device_driver_unregister(&ssam_kip_hub_driver);
- ssam_device_driver_unregister(&ssam_base_hub_driver);
platform_driver_unregister(&ssam_platform_hub_driver);
}
module_exit(ssam_device_hub_exit);
--
2.34.0
2.34.1

View file

@ -1,4 +1,4 @@
From 51b8004cee8b77ca57d6e673f69ad01db027780f Mon Sep 17 00:00:00 2001
From ef39b0db8969530a47efc2800eca262da0d3eaa7 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Sat, 25 Jul 2020 17:19:53 +0200
Subject: [PATCH] i2c: acpi: Implement RawBytes read access
@ -108,9 +108,9 @@ index 546cc935e035..006e25a1b0d5 100644
dev_warn(&adapter->dev, "protocol 0x%02x not supported for client 0x%02x\n",
accessor_type, client->addr);
--
2.34.0
2.34.1
From 7921182d0b377eda3ac117024da198f7e8f9f369 Mon Sep 17 00:00:00 2001
From c54b331b84b85ee8fea6bd8d54e235dd6107fd35 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Sat, 13 Feb 2021 16:41:18 +0100
Subject: [PATCH] platform/surface: Add driver for Surface Book 1 dGPU switch
@ -331,5 +331,5 @@ index 000000000000..8b816ed8f35c
+MODULE_DESCRIPTION("Discrete GPU Power-Switch for Surface Book 1");
+MODULE_LICENSE("GPL");
--
2.34.0
2.34.1

View file

@ -1,4 +1,4 @@
From e5d18337cb2a055e3f19917a5a2587613ef76745 Mon Sep 17 00:00:00 2001
From 5599604f3d6406df4e069178a82c23aaa2da4d59 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Sun, 10 Oct 2021 00:02:44 +0200
Subject: [PATCH] platform/surface: gpe: Add support for Surface Laptop Studio
@ -44,9 +44,9 @@ index 86f6991b1215..c1775db29efb 100644
};
--
2.34.0
2.34.1
From 7bf49aa10c27435251ff823e2d08db5fc7dd877b Mon Sep 17 00:00:00 2001
From 370d8986daff0e16c95c35e36351d9b9ae79119d Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Wed, 27 Oct 2021 00:56:11 +0200
Subject: [PATCH] platform/surface: gpe: Add support for Surface Pro 8
@ -81,5 +81,5 @@ index c1775db29efb..ec66fde28e75 100644
.ident = "Surface Book 1",
.matches = {
--
2.34.0
2.34.1

View file

@ -1,4 +1,4 @@
From 8d235d1ccb585797d8cb2b3cc0bae937d0cea076 Mon Sep 17 00:00:00 2001
From c9a7f8e1da0eae318e6d3ce6f1da0ab4f36123c0 Mon Sep 17 00:00:00 2001
From: Sachi King <nakato@nakato.io>
Date: Tue, 5 Oct 2021 00:05:09 +1100
Subject: [PATCH] Input: soc_button_array - support AMD variant Surface devices
@ -73,9 +73,9 @@ index cb6ec59a045d..4e8944f59def 100644
/*
--
2.34.0
2.34.1
From 849e2e434adbf97416e685a2b454341e0a5564ff Mon Sep 17 00:00:00 2001
From 9f7f2f05335a15d11460808e906a9c6c60348e54 Mon Sep 17 00:00:00 2001
From: Sachi King <nakato@nakato.io>
Date: Tue, 5 Oct 2021 00:22:57 +1100
Subject: [PATCH] platform/surface: surfacepro3_button: don't load on amd
@ -145,5 +145,5 @@ index 242fb690dcaf..30eea54dbb47 100644
--
2.34.0
2.34.1

View file

@ -1,4 +1,4 @@
From 201f8f1e60b5ea52ace9bc817b490e546b91f945 Mon Sep 17 00:00:00 2001
From 7920f530029819442106d5bbdf3662c235f25333 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jonas=20Dre=C3=9Fler?= <verdre@v0yd.nl>
Date: Thu, 5 Nov 2020 13:09:45 +0100
Subject: [PATCH] hid/multitouch: Turn off Type Cover keyboard backlight when
@ -34,7 +34,7 @@ Patchset: surface-typecover
1 file changed, 98 insertions(+), 2 deletions(-)
diff --git a/drivers/hid/hid-multitouch.c b/drivers/hid/hid-multitouch.c
index 3ea7cb1cda84..92fb053e0dd2 100644
index e1afddb7b33d..c15600b04b28 100644
--- a/drivers/hid/hid-multitouch.c
+++ b/drivers/hid/hid-multitouch.c
@@ -34,7 +34,10 @@
@ -81,7 +81,7 @@ index 3ea7cb1cda84..92fb053e0dd2 100644
};
static void mt_post_parse_default_settings(struct mt_device *td,
@@ -210,6 +219,7 @@ static void mt_post_parse(struct mt_device *td, struct mt_application *app);
@@ -211,6 +220,7 @@ static void mt_post_parse(struct mt_device *td, struct mt_application *app);
#define MT_CLS_GOOGLE 0x0111
#define MT_CLS_RAZER_BLADE_STEALTH 0x0112
#define MT_CLS_SMART_TECH 0x0113
@ -89,7 +89,7 @@ index 3ea7cb1cda84..92fb053e0dd2 100644
#define MT_DEFAULT_MAXCONTACT 10
#define MT_MAX_MAXCONTACT 250
@@ -378,6 +388,16 @@ static const struct mt_class mt_classes[] = {
@@ -386,6 +396,16 @@ static const struct mt_class mt_classes[] = {
MT_QUIRK_CONTACT_CNT_ACCURATE |
MT_QUIRK_SEPARATE_APP_REPORT,
},
@ -106,7 +106,7 @@ index 3ea7cb1cda84..92fb053e0dd2 100644
{ }
};
@@ -1690,6 +1710,69 @@ static void mt_expired_timeout(struct timer_list *t)
@@ -1698,6 +1718,69 @@ static void mt_expired_timeout(struct timer_list *t)
clear_bit(MT_IO_FLAGS_RUNNING, &td->mt_io_flags);
}
@ -176,7 +176,7 @@ index 3ea7cb1cda84..92fb053e0dd2 100644
static int mt_probe(struct hid_device *hdev, const struct hid_device_id *id)
{
int ret, i;
@@ -1713,6 +1796,9 @@ static int mt_probe(struct hid_device *hdev, const struct hid_device_id *id)
@@ -1721,6 +1804,9 @@ static int mt_probe(struct hid_device *hdev, const struct hid_device_id *id)
td->inputmode_value = MT_INPUTMODE_TOUCHSCREEN;
hid_set_drvdata(hdev, td);
@ -186,7 +186,7 @@ index 3ea7cb1cda84..92fb053e0dd2 100644
INIT_LIST_HEAD(&td->applications);
INIT_LIST_HEAD(&td->reports);
@@ -1742,15 +1828,19 @@ static int mt_probe(struct hid_device *hdev, const struct hid_device_id *id)
@@ -1750,15 +1836,19 @@ static int mt_probe(struct hid_device *hdev, const struct hid_device_id *id)
timer_setup(&td->release_timer, mt_expired_timeout, 0);
ret = hid_parse(hdev);
@ -208,7 +208,7 @@ index 3ea7cb1cda84..92fb053e0dd2 100644
ret = sysfs_create_group(&hdev->dev.kobj, &mt_attribute_group);
if (ret)
@@ -1802,6 +1892,7 @@ static void mt_remove(struct hid_device *hdev)
@@ -1810,6 +1900,7 @@ static void mt_remove(struct hid_device *hdev)
{
struct mt_device *td = hid_get_drvdata(hdev);
@ -216,7 +216,7 @@ index 3ea7cb1cda84..92fb053e0dd2 100644
del_timer_sync(&td->release_timer);
sysfs_remove_group(&hdev->dev.kobj, &mt_attribute_group);
@@ -2159,6 +2250,11 @@ static const struct hid_device_id mt_devices[] = {
@@ -2172,6 +2263,11 @@ static const struct hid_device_id mt_devices[] = {
MT_USB_DEVICE(USB_VENDOR_ID_XIROKU,
USB_DEVICE_ID_XIROKU_CSR2) },
@ -229,5 +229,5 @@ index 3ea7cb1cda84..92fb053e0dd2 100644
{ .driver_data = MT_CLS_GOOGLE,
HID_DEVICE(HID_BUS_ANY, HID_GROUP_ANY, USB_VENDOR_ID_GOOGLE,
--
2.34.0
2.34.1

View file

@ -1,4 +1,4 @@
From 4547c3e93ef3e729bbcb2b543d55db035758884d Mon Sep 17 00:00:00 2001
From dc3abd956d19823e9a63cb5e610bb4abded6bf23 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Mon, 5 Apr 2021 23:56:53 +0100
Subject: [PATCH] media: ipu3-cio2: Toggle sensor streaming in pm runtime ops
@ -56,9 +56,9 @@ index 47db0ee0fcbf..7bb86e246ebe 100644
return r;
}
--
2.34.0
2.34.1
From ed7153ed32df12093217aac29cdd2326ba54d855 Mon Sep 17 00:00:00 2001
From f586f8e0018b26cf88c88414ee3959af4d4ce56c Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Mon, 5 Apr 2021 23:56:54 +0100
Subject: [PATCH] media: i2c: Add support for ov5693 sensor
@ -1699,9 +1699,9 @@ index 000000000000..9499ee10f56c
+MODULE_DESCRIPTION("A low-level driver for OmniVision 5693 sensors");
+MODULE_LICENSE("GPL");
--
2.34.0
2.34.1
From bd3a19331b70e12398b1d0539b8a63ea1e706f15 Mon Sep 17 00:00:00 2001
From 85ffd222d01c40e128bcd79a0184ab91370a7781 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Fabian=20W=C3=BCthrich?= <me@fabwu.ch>
Date: Fri, 22 Jan 2021 20:58:13 +0100
Subject: [PATCH] cio2-bridge: Parse sensor orientation and rotation
@ -1862,9 +1862,9 @@ index dd0ffcafa489..924d99d20328 100644
struct property_entry ep_properties[5];
struct property_entry dev_properties[3];
--
2.34.0
2.34.1
From 3944848bd239da71a84da04744f79d545c59ba0b Mon Sep 17 00:00:00 2001
From 7f7e66ee218d2094cf359853105307ddc64fdb83 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Fabian=20W=C3=BCthrich?= <me@fabwu.ch>
Date: Sun, 24 Jan 2021 11:07:42 +0100
Subject: [PATCH] cio2-bridge: Use macros and add warnings
@ -1966,9 +1966,9 @@ index 924d99d20328..e1e388cc9f45 100644
(const struct cio2_sensor_config) { \
.hid = _HID, \
--
2.34.0
2.34.1
From 176b447057730b4b46fc6849c10c0e6626615ec8 Mon Sep 17 00:00:00 2001
From 5927b9839755dd08804383d1f26b54f726bd740e Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Fabian=20W=C3=BCthrich?= <me@fabwu.ch>
Date: Thu, 6 May 2021 07:52:44 +0200
Subject: [PATCH] cio2-bridge: Use correct dev_properties size
@ -1992,9 +1992,9 @@ index e1e388cc9f45..deaf5804f70d 100644
struct software_node_ref_args local_ref[1];
struct software_node_ref_args remote_ref[1];
--
2.34.0
2.34.1
From 0c87341184c2648c3c06d3f5427f5b90f8d28c2b Mon Sep 17 00:00:00 2001
From 4cc132d46312738a3f6b91c6b5773b501637bcff Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Thu, 20 May 2021 23:31:04 +0100
Subject: [PATCH] media: i2c: Fix vertical flip in ov5693
@ -2027,9 +2027,9 @@ index 9499ee10f56c..c558f9b48c83 100644
#define OV5693_FORMAT1_VBIN_EN BIT(0)
#define OV5693_FORMAT2_REG 0x3821
--
2.34.0
2.34.1
From 5ec90cd51e3c04c4e6f332d7b0743b3fe84ab34c Mon Sep 17 00:00:00 2001
From 786789f8262be5ba866e5e2efaa9a9a573a254e8 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Fri, 9 Jul 2021 16:39:18 +0100
Subject: [PATCH] media: i2c: Add ACPI support to ov8865
@ -2078,9 +2078,9 @@ index ce50f3ea87b8..7626c8608f8f 100644
},
.probe_new = ov8865_probe,
--
2.34.0
2.34.1
From e289d38251e1bf130529e0f87b97d62eef1076a0 Mon Sep 17 00:00:00 2001
From 1fc38d0380ea41a853258e50e9f45001560daa70 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Sat, 10 Jul 2021 21:20:17 +0100
Subject: [PATCH] media: i2c: Fix incorrect value in comment
@ -2109,9 +2109,9 @@ index 7626c8608f8f..8e3f8a554452 100644
static const struct ov8865_pll2_config ov8865_pll2_config_binning = {
--
2.34.0
2.34.1
From 10cb83df7098267af0168d56ef7fc4f67c304463 Mon Sep 17 00:00:00 2001
From 9381c6cea9c6a14c43a1b45ff495e7c576aed394 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Sat, 10 Jul 2021 22:21:52 +0100
Subject: [PATCH] media: i2c: Defer probe if not endpoint found
@ -2146,9 +2146,9 @@ index 8e3f8a554452..9bc8d5d8199b 100644
sensor->endpoint.bus_type = V4L2_MBUS_CSI2_DPHY;
--
2.34.0
2.34.1
From f6df0de5455d4e7c545e9d1414f505408b1d83c8 Mon Sep 17 00:00:00 2001
From 44c953b19417961130ea39c1dc70ddd86492c5e6 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Sat, 10 Jul 2021 22:00:25 +0100
Subject: [PATCH] media: i2c: Support 19.2MHz input clock in ov8865
@ -2505,9 +2505,9 @@ index 9bc8d5d8199b..4ddc1b277cc0 100644
subdev = &sensor->subdev;
--
2.34.0
2.34.1
From 64cf02f0238f2148a61f1445a23f46e2376c07b3 Mon Sep 17 00:00:00 2001
From b4f347d3b44d6d6b937eef8409dc25af51562921 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Sat, 10 Jul 2021 22:19:10 +0100
Subject: [PATCH] media: i2c: Add .get_selection() support to ov8865
@ -2610,9 +2610,9 @@ index 4ddc1b277cc0..0f2776390a8e 100644
static const struct v4l2_subdev_ops ov8865_subdev_ops = {
--
2.34.0
2.34.1
From c685ea62717adfc5a6b7786c84beeb0ddefc5d48 Mon Sep 17 00:00:00 2001
From c852e662efdc73eda2249e576084d92744337322 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Sat, 10 Jul 2021 22:34:43 +0100
Subject: [PATCH] media: i2c: Switch control to V4L2_CID_ANALOGUE_GAIN
@ -2663,9 +2663,9 @@ index 0f2776390a8e..a832938c33b6 100644
/* White Balance */
--
2.34.0
2.34.1
From 33d5d3d69ff328d59e656a84916e09efc04280b3 Mon Sep 17 00:00:00 2001
From a8a73033cf32bd3e4b8aee14f73df4bb70cde615 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Mon, 12 Jul 2021 22:54:56 +0100
Subject: [PATCH] media: i2c: Add vblank control to ov8865
@ -2773,9 +2773,9 @@ index a832938c33b6..f741c0713ca4 100644
if (ret)
goto error_mutex;
--
2.34.0
2.34.1
From 890118a42388ea2b1b3ccec16098cd613cb19bb7 Mon Sep 17 00:00:00 2001
From 058ace8125bed8cd72aaeab86e16baa12e7a9c15 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Tue, 13 Jul 2021 23:40:33 +0100
Subject: [PATCH] media: i2c: Add hblank control to ov8865
@ -2843,9 +2843,9 @@ index f741c0713ca4..4b18cc80f985 100644
mutex_unlock(&sensor->mutex);
--
2.34.0
2.34.1
From ce3d01c32ae5452276954808c8dd4019094484b9 Mon Sep 17 00:00:00 2001
From 30aff5381e7b70caba31f0123d1d5cf5ef7b5889 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Wed, 20 Oct 2021 22:43:54 +0100
Subject: [PATCH] media: i2c: Update HTS values in ov8865
@ -3019,9 +3019,9 @@ index 4b18cc80f985..1b8674152750 100644
.set_selection = ov8865_get_selection,
};
--
2.34.0
2.34.1
From 3d44ca77687483dde080710cacfe4ff084967ec7 Mon Sep 17 00:00:00 2001
From 475fdc73fac3d94a9bb4ebc559522606b6e4b4c4 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Tue, 13 Jul 2021 23:43:17 +0100
Subject: [PATCH] media: i2c: cap exposure at height + vblank in ov8865
@ -3102,9 +3102,9 @@ index 1b8674152750..99548ad15dcd 100644
mutex_unlock(&sensor->mutex);
--
2.34.0
2.34.1
From 2343d89b8c61142274fec03fe040b68572dff5c5 Mon Sep 17 00:00:00 2001
From d38e1c5cc642d571545576b1689e64ec61a58367 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Fri, 16 Jul 2021 22:56:15 +0100
Subject: [PATCH] media: i2c: Add controls from fwnode to ov8865
@ -3147,9 +3147,9 @@ index 99548ad15dcd..dfb5095ef16b 100644
ret = handler->error;
goto error_ctrls;
--
2.34.0
2.34.1
From 244715f3ba0a2efd811de64d6c86f08d1eba09a6 Mon Sep 17 00:00:00 2001
From 95b53f575a01e6be671c768aff6f23f043738b02 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Fri, 16 Jul 2021 00:00:54 +0100
Subject: [PATCH] media: i2c: Switch exposure control unit to lines
@ -3194,9 +3194,9 @@ index dfb5095ef16b..5f19d82554df 100644
/* Gain */
--
2.34.0
2.34.1
From 50cebe47b4dc67e00c7f5ec83cc8fb1a44c90c6d Mon Sep 17 00:00:00 2001
From 184601fa2dbb843d2bc2a58ded4353977d0f44a7 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Tue, 24 Aug 2021 22:39:02 +0100
Subject: [PATCH] media: i2c: Re-order runtime pm initialisation
@ -3230,9 +3230,9 @@ index 5f19d82554df..18b5f1e8e9a7 100644
/* V4L2 subdev register */
--
2.34.0
2.34.1
From 5351b7b5f210077f3c7b05aa9b02c992960b8748 Mon Sep 17 00:00:00 2001
From bc8038eb895135b21c88aa2935a05292d09ed6c5 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Tue, 24 Aug 2021 23:17:39 +0100
Subject: [PATCH] media: i2c: Use dev_err_probe() in ov8865
@ -3313,9 +3313,9 @@ index 18b5f1e8e9a7..19e6bebf340d 100644
sensor->extclk = devm_clk_get(dev, NULL);
--
2.34.0
2.34.1
From 723560e37c7a4fbdb988c4e463159da599c46631 Mon Sep 17 00:00:00 2001
From 07897b72d279d4e3038cfb3bca7b66e42dacf811 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Wed, 14 Jul 2021 00:05:04 +0100
Subject: [PATCH] media: ipu3-cio2: Add INT347A to cio2-bridge
@ -3346,9 +3346,9 @@ index 7e582135dfb8..0132f0bd9b41 100644
CIO2_SENSOR_CONFIG("OVTI2680", 0),
};
--
2.34.0
2.34.1
From 049ac8825414795696bccb84aeb5102b4da18e4e Mon Sep 17 00:00:00 2001
From cdd94eed60a96465d7bf0f93d027b598a46a4e3d Mon Sep 17 00:00:00 2001
From: Hans de Goede <hdegoede@redhat.com>
Date: Thu, 7 Oct 2021 15:34:52 +0200
Subject: [PATCH] media: i2c: ov8865: Fix lockdep error
@ -3392,9 +3392,9 @@ index 19e6bebf340d..d5af8aedf5e8 100644
goto error_ctrls;
--
2.34.0
2.34.1
From 09dc5cbbd964d92610c4709980a14062c86aea4b Mon Sep 17 00:00:00 2001
From 949f16a4f29c529ed1537b1b822c8a6791ca50d2 Mon Sep 17 00:00:00 2001
From: Hans de Goede <hdegoede@redhat.com>
Date: Sun, 10 Oct 2021 20:56:57 +0200
Subject: [PATCH] ACPI: delay enumeration of devices with a _DEP pointing to an
@ -3455,7 +3455,7 @@ Patchset: cameras
2 files changed, 38 insertions(+), 3 deletions(-)
diff --git a/drivers/acpi/scan.c b/drivers/acpi/scan.c
index 770b82483d74..f82cc35c6e40 100644
index 5b54c80b9d32..efee6ee91c8f 100644
--- a/drivers/acpi/scan.c
+++ b/drivers/acpi/scan.c
@@ -796,6 +796,12 @@ static const char * const acpi_ignore_dep_ids[] = {
@ -3575,9 +3575,9 @@ index 13d93371790e..2da53b7b4965 100644
struct acpi_device *
acpi_dev_get_next_match_dev(struct acpi_device *adev, const char *hid, const char *uid, s64 hrv);
--
2.34.0
From 9c7d3cfe6294ec72a2ce9c97c040a46ada4473c3 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Sun, 31 Oct 2021 18:07:39 +0100
Subject: [PATCH] platform/surface: aggregator_registry: Use KIP hub for
Surface Book 3 base devices
It turns out that the Surface Book 3 manages the devices contained in
its detachable base via the KIP hub as well, similarly to the Surface
Pro 8 and Surface Pro X. So move them over to the KIP hub.
Right now, we (mis-)use the detachment subsystem (DTX), which is
designed for handling detachment requests and physical locking of the
base, to properly remove and re-attach Surface System Aggregator Module
(SSAM) client devices contained in the base. This system does not seem
to be intended for managing the (sub-)devices contained in the base,
which may need some time to be set up properly.
The KIP subsystem seems to be the intended subsystem for managing those
devices, thus let's use that one instead.
Note that this also changes the way in which devices on the Surface Book
3 are removed when they have been detached, specifically from normal
removal to hot-removal (avoiding further communication with the embedded
controller). It seems that the "communication timeout after device
removal" issue does also occur on the Surface Book 3, but has so far
been missed as it does not happen reliably every time. Switching to
hot-removal fixes this issue and should not have any noticable
drawbacks.
Signed-off-by: Maximilian Luz <luzmaximilian@gmail.com>
Patchset: surface-sam
---
.../surface/surface_aggregator_registry.c | 56 ++++++-------------
1 file changed, 16 insertions(+), 40 deletions(-)
diff --git a/drivers/platform/surface/surface_aggregator_registry.c b/drivers/platform/surface/surface_aggregator_registry.c
index eaf0054627a5..d17f656b2dad 100644
--- a/drivers/platform/surface/surface_aggregator_registry.c
+++ b/drivers/platform/surface/surface_aggregator_registry.c
@@ -41,13 +41,7 @@ static const struct software_node ssam_node_root = {
.name = "ssam_platform_hub",
};
-/* Base device hub (devices attached to Surface Book 3 base). */
-static const struct software_node ssam_node_hub_base = {
- .name = "ssam:00:00:02:00:00",
- .parent = &ssam_node_root,
-};
-
-/* KIP device hub (connects keyboard cover devices on Surface Pro 8). */
+/* KIP device hub (connects detachable keyboard/touchpad on Surface Pro 8 and Book 3). */
static const struct software_node ssam_node_hub_kip = {
.name = "ssam:01:0e:01:00:00",
.parent = &ssam_node_root,
@@ -65,10 +59,10 @@ static const struct software_node ssam_node_bat_main = {
.parent = &ssam_node_root,
};
-/* Secondary battery (Surface Book 3). */
-static const struct software_node ssam_node_bat_sb3base = {
+/* Secondary battery (Surface Book 3, managed via KIP hub). */
+static const struct software_node ssam_node_bat_kip = {
.name = "ssam:01:02:02:01:00",
- .parent = &ssam_node_hub_base,
+ .parent = &ssam_node_hub_kip,
};
/* Platform profile / performance-mode device. */
@@ -143,30 +137,6 @@ static const struct software_node ssam_node_hid_main_iid5 = {
.parent = &ssam_node_root,
};
-/* HID keyboard (base hub). */
-static const struct software_node ssam_node_hid_base_keyboard = {
- .name = "ssam:01:15:02:01:00",
- .parent = &ssam_node_hub_base,
-};
-
-/* HID touchpad (base hub). */
-static const struct software_node ssam_node_hid_base_touchpad = {
- .name = "ssam:01:15:02:03:00",
- .parent = &ssam_node_hub_base,
-};
-
-/* HID device instance 5 (unknown HID device, base hub). */
-static const struct software_node ssam_node_hid_base_iid5 = {
- .name = "ssam:01:15:02:05:00",
- .parent = &ssam_node_hub_base,
-};
-
-/* HID device instance 6 (unknown HID device, base hub). */
-static const struct software_node ssam_node_hid_base_iid6 = {
- .name = "ssam:01:15:02:06:00",
- .parent = &ssam_node_hub_base,
-};
-
/* HID keyboard (KIP hub). */
static const struct software_node ssam_node_hid_kip_keyboard = {
.name = "ssam:01:15:02:01:00",
@@ -191,6 +161,12 @@ static const struct software_node ssam_node_hid_kip_iid5 = {
.parent = &ssam_node_hub_kip,
};
+/* HID device instance 6 (KIP hub, unknown HID device). */
+static const struct software_node ssam_node_hid_kip_iid6 = {
+ .name = "ssam:01:15:02:06:00",
+ .parent = &ssam_node_hub_kip,
+};
+
/*
* Devices for 5th- and 6th-generations models:
* - Surface Book 2,
@@ -206,16 +182,16 @@ static const struct software_node *ssam_node_group_gen5[] = {
/* Devices for Surface Book 3. */
static const struct software_node *ssam_node_group_sb3[] = {
&ssam_node_root,
- &ssam_node_hub_base,
+ &ssam_node_hub_kip,
&ssam_node_bat_ac,
&ssam_node_bat_main,
- &ssam_node_bat_sb3base,
+ &ssam_node_bat_kip,
&ssam_node_tmp_pprof,
&ssam_node_bas_dtx,
- &ssam_node_hid_base_keyboard,
- &ssam_node_hid_base_touchpad,
- &ssam_node_hid_base_iid5,
- &ssam_node_hid_base_iid6,
+ &ssam_node_hid_kip_keyboard,
+ &ssam_node_hid_kip_touchpad,
+ &ssam_node_hid_kip_iid5,
+ &ssam_node_hid_kip_iid6,
NULL,
};
--
2.34.0
2.34.1
From dfaf598c4fc341f2d0bb4e90b5105cce85cb1456 Mon Sep 17 00:00:00 2001
From 2026a4b43b15470d533e51a22989005563080789 Mon Sep 17 00:00:00 2001
From: Hans de Goede <hdegoede@redhat.com>
Date: Sun, 10 Oct 2021 20:56:58 +0200
Subject: [PATCH] i2c: acpi: Use acpi_dev_ready_for_enumeration() helper
@ -3627,9 +3627,9 @@ index 006e25a1b0d5..ff7f5cbb5c73 100644
return -ENODEV;
--
2.34.0
2.34.1
From 4a4e1b79949baf780d6025b5fe29205da88b7232 Mon Sep 17 00:00:00 2001
From 7926ff1a5bf60d56091fcbd03ed6285d549ef4fd Mon Sep 17 00:00:00 2001
From: Hans de Goede <hdegoede@redhat.com>
Date: Sun, 10 Oct 2021 20:56:59 +0200
Subject: [PATCH] platform_data: Add linux/platform_data/tps68470.h file
@ -3700,9 +3700,9 @@ index 000000000000..126d082c3f2e
+
+#endif
--
2.34.0
2.34.1
From 5c4563ae09165743a04617ac2d99d687664e3a91 Mon Sep 17 00:00:00 2001
From 02b739910ebb60e6aa554e8d1dcbbbf10bbdb730 Mon Sep 17 00:00:00 2001
From: Hans de Goede <hdegoede@redhat.com>
Date: Sun, 10 Oct 2021 20:57:00 +0200
Subject: [PATCH] regulator: Introduce tps68470-regulator driver
@ -3962,9 +3962,9 @@ index 000000000000..3129fa13a122
+MODULE_DESCRIPTION("TPS68470 voltage regulator driver");
+MODULE_LICENSE("GPL v2");
--
2.34.0
2.34.1
From 7cc2e5fc54b76a9b82e400380233ad3e2033f6bb Mon Sep 17 00:00:00 2001
From 285719dd8e62a694d024641bd279626bdc78481f Mon Sep 17 00:00:00 2001
From: Hans de Goede <hdegoede@redhat.com>
Date: Sun, 10 Oct 2021 20:57:01 +0200
Subject: [PATCH] clk: Introduce clk-tps68470 driver
@ -4307,9 +4307,9 @@ index ffe81127d91c..7807fa329db0 100644
#define TPS68470_GPIO_CTL_REG_B(x) (TPS68470_REG_GPCTL0B + (x) * 2)
#define TPS68470_GPIO_MODE_MASK GENMASK(1, 0)
--
2.34.0
2.34.1
From 73d1915be2172618e34e472b377abe13b46e3802 Mon Sep 17 00:00:00 2001
From c8cfdc22eefcf36ba2285ade00ee76b338148c5b Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Sun, 10 Oct 2021 20:57:02 +0200
Subject: [PATCH] platform/x86: int3472: Enable I2c daisy chain
@ -4344,9 +4344,9 @@ index c05b4cf502fe..42e688f4cad4 100644
return 0;
--
2.34.0
2.34.1
From 7cf09f4b33bf89ee11ea0b7bb06868756477968c Mon Sep 17 00:00:00 2001
From af677646d33e57829f40c9dc9cf8fd3887cbe150 Mon Sep 17 00:00:00 2001
From: Hans de Goede <hdegoede@redhat.com>
Date: Sun, 10 Oct 2021 20:57:03 +0200
Subject: [PATCH] platform/x86: int3472: Split into 2 drivers
@ -4603,9 +4603,9 @@ index 42e688f4cad4..b94cf66ab61f 100644
+MODULE_AUTHOR("Daniel Scally <djrscally@gmail.com>");
+MODULE_LICENSE("GPL v2");
--
2.34.0
2.34.1
From 67cc6e89c0dbf48452e87af6e6ae432a91e45ad4 Mon Sep 17 00:00:00 2001
From c5fe063ea3e7ab196282e4fa300416ecd6fb7bb2 Mon Sep 17 00:00:00 2001
From: Hans de Goede <hdegoede@redhat.com>
Date: Sun, 10 Oct 2021 20:57:04 +0200
Subject: [PATCH] platform/x86: int3472: Add get_sensor_adev_and_name() helper
@ -4716,9 +4716,9 @@ index a19a1f5dbdd7..efd31a0c7a88 100644
static int skl_int3472_discrete_remove(struct platform_device *pdev)
--
2.34.0
2.34.1
From a614e01a6dae58a8688c95a084d9f7ee1691949a Mon Sep 17 00:00:00 2001
From 216407dfbd4bc53b4a52cf7231e028f7a1fc4b1f Mon Sep 17 00:00:00 2001
From: Hans de Goede <hdegoede@redhat.com>
Date: Sun, 10 Oct 2021 20:57:05 +0200
Subject: [PATCH] platform/x86: int3472: Pass tps68470_clk_platform_data to the
@ -4804,9 +4804,9 @@ index b94cf66ab61f..78e34e7b6969 100644
case DESIGNED_FOR_CHROMEOS:
ret = devm_mfd_add_devices(&client->dev, PLATFORM_DEVID_NONE,
--
2.34.0
2.34.1
From d58eb7dd1306509423c26201e9adac731830fdbc Mon Sep 17 00:00:00 2001
From e9e1dc30e20dff9add6ad9db0d090ee674955b83 Mon Sep 17 00:00:00 2001
From: Hans de Goede <hdegoede@redhat.com>
Date: Sun, 10 Oct 2021 20:57:06 +0200
Subject: [PATCH] platform/x86: int3472: Pass tps68470_regulator_platform_data
@ -5098,9 +5098,9 @@ index 000000000000..96954a789bb8
+ return NULL;
+}
--
2.34.0
2.34.1
From f3a1a8e151645e77e7c93410a1027c9dc84d4b42 Mon Sep 17 00:00:00 2001
From 8e07d6fbb495a64919bc5c687e3ce89a1ca42f88 Mon Sep 17 00:00:00 2001
From: Hans de Goede <hdegoede@redhat.com>
Date: Sun, 10 Oct 2021 20:57:07 +0200
Subject: [PATCH] platform/x86: int3472: Deal with probe ordering issues
@ -5182,9 +5182,9 @@ index aae24d228770..21c6c1a6edfc 100644
MODULE_LICENSE("GPL v2");
+MODULE_SOFTDEP("pre: clk-tps68470 tps68470-regulator");
--
2.34.0
2.34.1
From 969161d8a085f9631afc3fe36e0935bb0fce20dc Mon Sep 17 00:00:00 2001
From 79948436334a10b65f07887d74df3a67169a10f4 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Thu, 4 Nov 2021 21:46:27 +0000
Subject: [PATCH] media: i2c: Add integration time margin to ov8865
@ -5224,9 +5224,9 @@ index d5af8aedf5e8..966487e32bfe 100644
sensor->ctrls.exposure->minimum,
exposure_max,
--
2.34.0
2.34.1
From 1d7039aca5bcd17dde3edd522d1288b2e3325021 Mon Sep 17 00:00:00 2001
From 2df251c3a3d78d09ba613d9ea8a9931b8d2ed254 Mon Sep 17 00:00:00 2001
From: Daniel Scally <djrscally@gmail.com>
Date: Thu, 4 Nov 2021 21:48:38 +0000
Subject: [PATCH] media: i2c: Fix max gain in ov8865
@ -5256,5 +5256,5 @@ index 966487e32bfe..6c78edb65d1e 100644
/* White Balance */
--
2.34.0
2.34.1

View file

@ -1,4 +1,4 @@
From 34c109617bb6001450e9b54273f1755e8ad16122 Mon Sep 17 00:00:00 2001
From f062218991aeb52f3b4d90d34a02619237cbc956 Mon Sep 17 00:00:00 2001
From: Sachi King <nakato@nakato.io>
Date: Sat, 29 May 2021 17:47:38 +1000
Subject: [PATCH] ACPI: Add quirk for Surface Laptop 4 AMD missing irq 7
@ -63,9 +63,9 @@ index 14bcd59bcdee..159d26a664ca 100644
mp_config_acpi_legacy_irqs();
--
2.34.0
2.34.1
From 8224097ce2d59e87a3d03e6dc0c4fa5e9780e080 Mon Sep 17 00:00:00 2001
From 9fe368de3be59b3b450805af8fb929c447e48600 Mon Sep 17 00:00:00 2001
From: Maximilian Luz <luzmaximilian@gmail.com>
Date: Thu, 3 Jun 2021 14:04:26 +0200
Subject: [PATCH] ACPI: Add AMD 13" Surface Laptop 4 model to irq 7 override
@ -105,5 +105,5 @@ index 159d26a664ca..77cd54849a8b 100644
};
--
2.34.0
2.34.1

View file

@ -1,4 +1,4 @@
From b76d74360172ebad0e32954a23b69c299fba2f58 Mon Sep 17 00:00:00 2001
From f18c91e5e1b6eb5cc0ff4590e295f03aaf02fa7e Mon Sep 17 00:00:00 2001
From: Mathias Nyman <mathias.nyman@linux.intel.com>
Date: Fri, 29 Oct 2021 15:51:54 +0300
Subject: [PATCH] xhci: Fix commad ring abort, write all 64 bits to CRCR
@ -66,5 +66,5 @@ index 311597bba80e..eaa49aef2935 100644
/* Section 4.6.1.2 of xHCI 1.0 spec says software should also time the
* completion of the Command Abort operation. If CRR is not negated in 5
--
2.34.0
2.34.1

View file

@ -49,18 +49,18 @@ sha256sums=('SKIP'
'e2d8d59ee965f5fabcb9dd15b70074798e168ccdbd75a9540390c281279f113d'
'63e0aa01e590c789a2a312f48cdc467b29734465cdf87e206b7a7e0f82e22bc4'
'b30cd71018df7e98101ba0cf37054169006b096d2870a9f8467dd96378b02b98'
'7a8e1c0a1c36ea24cdf8671cb31784082f1771f65b3f87adfc3294eea6aedaf5'
'e7f8fbd05591909b7884c70b8137978b1929959a4fc84c49525eadb6cd186a39'
'2e99f66856c67a19284b4a16b03df0e9e94c71b55c5089eb4aa77abfce85e2b3'
'315656874aa1ed677b0e098e3434fa5c37bb344eccd47ff90ee08902d193f09e'
'19d857a2aa03a707d34dcaf79e987b598493bd5207ae1824035bd88d53cfdf6d'
'84e9b3ad9ee18715478ec634c0fd20a2df0929bc51a836f134987eb0e54dcf63'
'1053c98c11cc73b5ec45b074c17cc88b85cb925e8b7ea5f9c9b700e9810e0bd5'
'5eca560b3763be758f74076be990b5eea5f276706fd409165112028ed40b5bb3'
'7214838fc83ddc93bdd462d957f2e1568bad7679f064af14c26e9a5858f24b0a'
'b973a24a3a7e07a44593e148748dc07a9a28310e1c5c3b8237ddb4c49e7a4668'
'65535a72bdc22dc318b6a080f827803bf79854ea2c78e07ea694b9eed417788f'
'df0f6b8acbd680661b59a24aa50fe0e25ed5bf697007802fb9e2200f3302a980')
'8a6cf5b4629c80bab9cf43ac9d5108952411891c4d15e0b8e01bbef48212a945'
'aa5bcea433957d45413eccfaa9c0a7a5a2470c6fd0b24613fcabbeb017402324'
'2a23425bf96d5e91a9715b1b55d287a9ef18a5b75a0904ed1be4f0569115c2c3'
'55c9ffd428de50f7250b6b9334c780eae7ad184f07a353d9fbe0721208142930'
'392c2a1bb2a45828bb1dc52b02d87fcfebe38fffa775b22688e0737329778eab'
'53ad85e8571537f82372045b2487dea94e07e6963b4d4c85432263788ae7c9d9'
'91f244a3a16b1f43737077d8b57ffea43d96047ad63173f224bbeaf69582e728'
'cea8089942a52e54dd9929c815a7c80c7182cc6625e9e6a264e60e1563b049c9'
'75d097a0cb00a6aeb20d0f695b9f4a723e794f41f852c45a1ef9638669d4ac36'
'752025540004c364f4f8508d307f5658b3e4087676cb5b7b956cd08513689bb2'
'f27b96e2f99f8dd5eeea704432ab8415cfbeba5a9d6eb97d764a2a98da99a214'
'0ed4d603f4e66b3ea6253c712ef7fd53cf08190be545edaf43577ea1fda6da99')
export KBUILD_BUILD_HOST=archlinux